@@ -5,7 +5,7 @@ from aws_cdk import (
     aws_sns as sns,
     aws_lambda as _lambda
 )
-from .disk_functions.construct import DiskFunctions
+from ..disk_functions.construct import DiskFunctions
 
 # TODO - May need to assign an IAM role to the step function
 class StepFunctionConstruct(cdk.Construct):
